/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface StorageBackupConfig extends cdktf.TerraformMetaArguments {
    /**
    * User defined key-value pairs to classify the storage.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.22.0/docs/resources/storage_backup#labels StorageBackup#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * The UUID of the storage to back up.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.22.0/docs/resources/storage_backup#source_storage StorageBackup#source_storage}
    */
    readonly sourceStorage: string;
    /**
    * Title of the backup.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.22.0/docs/resources/storage_backup#title StorageBackup#title}
    */
    readonly title: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.22.0/docs/resources/storage_backup upcloud_storage_backup}
*/
export declare class StorageBackup extends cdktf.TerraformResource {
    static readonly tfResourceType = "upcloud_storage_backup";
    /**
    * Generates CDKTF code for importing a StorageBackup resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the StorageBackup to import
    * @param importFromId The id of the existing StorageBackup that should be imported. Refer to the {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.22.0/docs/resources/storage_backup#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the StorageBackup to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/upcloudltd/upcloud/5.22.0/docs/resources/storage_backup upcloud_storage_backup} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options StorageBackupConfig
    */
    constructor(scope: Construct, id: string, config: StorageBackupConfig);
    get createdAt(): string;
    get encrypt(): cdktf.IResolvable;
    get id(): string;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    get size(): number;
    private _sourceStorage?;
    get sourceStorage(): string;
    set sourceStorage(value: string);
    get sourceStorageInput(): string | undefined;
    private _systemLabels;
    get systemLabels(): cdktf.StringMap;
    get tier(): string;
    private _title?;
    get title(): string;
    set title(value: string);
    get titleInput(): string | undefined;
    get type(): string;
    get zone(): string;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
